Description Usage Arguments Details Value Examples
Create a data frame of inputs from extraction .rds files for probability distribution estimation.
1 | alf_dist_inputs(project, in_dir)
|
project |
character, see details. |
in_dir |
path to data extractions, the parent directory with the three subdirectories, |
This function creates a data frame containing columns of metadata based on the .rds files
stored in the fsv, veg and age extraction subdirectories.
These files are output during ALFRESCO data extraction by run_alf_extraction.
The columns of the data frame describe the random variable set (fsv, veg or age),
location group (region set), specific location (region),
model (a GCM or CRU), RCP (including "historical"), and the fire management options (FMO) treatment.
If in_dir is not provided, a default is taken from alfdef()$alf_extract_dir and project, so project
must be provided. project is ignored if the full project path is provided via in_dir.
Provide a directory or provide a project name and rely on the default extractions directory.
a data frame.
1 | ## Not run: alf_dist_inputs("JFSP")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.