Description Usage Arguments Details Value Examples
Generate a data frame of mean (across replicates) annual burn area by fire management options zones.
1 2 3 |
in_dir |
input directory, a |
years |
integer. |
id |
integer, 0 through 5 available, pertaining to ID codes for FMO zones. |
labels |
character, labels for |
fmo_layer |
raster layer, optional. If |
mask |
character, optional mask: |
mask_value |
character, ecoregion or FMZ name to mask by, not applicable if |
Options for Alaska ecoregion and Alaska fire management zone masking include "Arctic Tundra", "Bering Taiga", "Bering Tundra" and "Intermontane Boreal" and
eight FMZs ("DAS", "FAS", "GAD", "MID", "SWS", "TAD", "TAS", "UYD"), respectively.
The limited sets represent their spatial intersections with the JFSP ALFRESCO spatial domain.
a data frame.
1 2 3 4 | ## Not run:
ba_fmo(".", 1950:2013, 0:5)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.